'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactJss = require('react-jss');
var reactDom = require('react-dom');
var parser = _interopDefault(require('html-react-parser'));
var reactTransitionGroup = require('react-transition-group');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var SFProText = "85b4043974a2a3be.otf";

var body1 = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.black;
  },
  fontSize: '16px',
  lineHeight: '24px',
  fontWeight: 400,
  fontFamily: 'SF Pro Text',
  margin: 0
};

var h3 = /*#__PURE__*/_extends({}, body1, {
  fontWeight: 600,
  color: function color(_ref2) {
    var palette = _ref2.theme.palette;
    return palette.dark_black;
  }
});

var h4 = /*#__PURE__*/_extends({}, h3, {
  fontSize: '14px',
  lineHeight: '18px'
});

var h2 = {
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontSize: '22px',
  lineHeight: '30px',
  color: function color(_ref3) {
    var palette = _ref3.theme.palette;
    return palette.dark_black;
  }
};
var label = {
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontWeight: 400,
  fontSize: '12px',
  lineHeight: '18px',
  color: function color(_ref4) {
    var palette = _ref4.theme.palette;
    return palette.dark_black;
  }
};
var title = {
  padding: 0,
  fontWeight: 600,
  fontSize: 16,
  fontFamily: 'SF Pro Text',
  lineHeight: '24px',
  textAlign: 'center',
  letterSpacing: '-0.0024em',
  margin: 0
};

var bigTitle = /*#__PURE__*/_extends({}, title, {
  fontSize: 34,
  lineHeight: '40px'
});

var useStyles = /*#__PURE__*/reactJss.createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  body1: body1,
  h2: h2,
  h3: h3,
  h4: h4,
  label: label,
  title: title,
  bigTitle: bigTitle
});

var palette = {
  primary: '#4B46EC',
  light: '#F0F0FF',
  black: '#121620',
  dark_black: '#232323',
  white: '#ffffff',
  extra_light: '#dee5f9',
  gray: '#f0f0f0',
  light_gray: '#c7c7c7',
  gray_200: '#8e8e93',
  gray_300: '#C5C5D1',
  error: '#FF5758',
  gray_400: '#E0E3EB',
  gray_500: '#868C99'
};

// node modules
var ThemeContext = /*#__PURE__*/React.createContext({
  palette: palette
});
var theming = /*#__PURE__*/reactJss.createTheming(ThemeContext);

var Typography = function Typography(_ref) {
  var className = _ref.className,
      variant = _ref.variant,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "variant", "children"]);

  var classes = useStyles({
    theme: theming.useTheme()
  });
  var variantClassName = classes[variant] ? classes[variant] : classes.body1;
  var typClassName = variantClassName + " " + className;
  return React__default.createElement("p", Object.assign({
    className: typClassName
  }, otherProps), children);
};

// node modules
var useStyles$1 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    outline: 'none',
    border: 'none',
    background: 'none',
    fontSize: 16,
    padding: '18px',
    cursor: 'pointer',
    transition: 'all .2s ease',
    minWidth: 150
  },
  disabledClass: {
    cursor: 'not-allowed',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return [[palette.black], '!important'];
    },
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return [[palette.light_gray], '!important'];
    }
  }
});

var SimpleButton = function SimpleButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      label = _ref.label,
      width = _ref.width,
      disabled = _ref.disabled,
      onClick = _ref.onClick,
      children = _ref.children,
      _ref$textTransform = _ref.textTransform,
      textTransform = _ref$textTransform === void 0 ? 'none' : _ref$textTransform,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label", "width", "disabled", "onClick", "children", "textTransform"]);

  var _useStyles = useStyles$1({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      disabledClass = _useStyles.disabledClass;

  var btnClassName = root + " " + className + " " + (disabled && disabledClass);

  var handleClick = function handleClick() {
    if (disabled) return;
    if (onClick) onClick();
  };

  return React__default.createElement("button", Object.assign({
    onClick: handleClick,
    style: {
      width: width,
      textTransform: textTransform
    },
    className: btnClassName
  }, otherProps), React__default.createElement(Typography, {
    variant: "title"
  }, label), children);
};

// node modules
var useStyles$2 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    borderRadius: '.5rem',
    transition: 'background-color .3s, color .3s',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    },
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.black;
    }
  },
  rootSelected: {
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.primary;
    },
    color: function color(_ref4) {
      var palette = _ref4.theme.palette;
      return palette.light;
    }
  }
});

var SelectButton = function SelectButton(_ref) {
  var className = _ref.className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "selected"]);

  var _useStyles = useStyles$2({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      rootSelected = _useStyles.rootSelected;

  var selectedClass = selected ? rootSelected : '';
  var selectBtnClass = root + " " + selectedClass + " " + className;
  return React__default.createElement(SimpleButton, Object.assign({
    className: selectBtnClass
  }, otherProps));
};

var img = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: %23066fde %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var alignment = {
  center: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center'
  },
  betweenCenter: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  rowCenter: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  }
};

var useStyles$3 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.betweenCenter),
  checkWrapper: /*#__PURE__*/_extends({
    borderRadius: '50%'
  }, alignment.center, {
    marginLeft: 8,
    minWidth: 24,
    width: 24,
    height: 24,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.white;
    }
  }),
  checkIconCl: {
    width: 12
  }
});

var CheckButton = function CheckButton(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["label", "className", "selected", "children"]);

  var _useStyles = useStyles$3({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      checkWrapper = _useStyles.checkWrapper,
      checkIconCl = _useStyles.checkIconCl;

  var checkBtnClass = root + " " + className;
  return React__default.createElement(SelectButton, Object.assign({
    selected: selected,
    label: label,
    className: checkBtnClass
  }, otherProps), children ? children : null, React__default.createElement("div", {
    className: checkWrapper
  }, selected && React__default.createElement("img", {
    className: checkIconCl,
    src: img,
    alt: ""
  })));
};

// node modules
var useStyles$4 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    borderRadius: '2em',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.primary;
    },
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.light;
    },
    '&:active': {
      color: function color(_ref3) {
        var palette = _ref3.theme.palette;
        return palette.black;
      },
      background: function background(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.light_gray;
      }
    }
  }
});

var PrimaryButton = function PrimaryButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label"]);

  var theme = theming.useTheme();

  var _useStyles = useStyles$4({
    theme: theme
  }),
      root = _useStyles.root;

  var primaryBtnClassName = root + " " + className;
  return React__default.createElement(SimpleButton, Object.assign({
    className: primaryBtnClassName,
    label: label
  }, otherProps));
};

var img$1 = "data:image/svg+xml,%3csvg width='23' height='14' viewBox='0 0 23 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M21.6161 0.450918C20.9883 -0.211053 20.1996 -0.10737 19.5366 0.52202L8.75873 10.8412L3.39961 5.42612C2.76194 4.77188 1.68996 4.33711 1.03516 4.97487C0.380914 5.61198 0.764157 6.5081 1.40128 7.16234L7.57427 13.5001C7.89776 13.8325 8.32769 14 8.75873 14C9.1677 14 9.57667 13.849 9.8969 13.5464L21.6366 2.41304C22.2991 1.78468 22.2449 1.11345 21.6161 0.450918Z' fill='%23202B47'/%3e%3c/svg%3e";

var img$2 = "data:image/svg+xml,%3csvg width='17' height='16' viewBox='0 0 17 16' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M0.607422 1.77734L2.3852 -0.000434061L16.6074 14.2218L14.8296 15.9996L0.607422 1.77734Z' fill='%23202B47'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M16.6074 1.77734L14.8296 -0.000434061L0.607422 14.2218L2.3852 15.9996L16.6074 1.77734Z' fill='%23202B47'/%3e%3c/svg%3e";

var useStyles$5 = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: /*#__PURE__*/_extends({}, alignment.center, {
    border: function border(_ref) {
      var palette = _ref.theme.palette;
      return "2px solid " + palette.gray_300;
    },
    borderRadius: 10,
    width: 160,
    paddingBottom: 15,
    paddingTop: 39,
    boxSizing: 'border-box'
  }),
  content: /*#__PURE__*/_extends({}, alignment.rowCenter, {
    width: 134
  }),
  icon: {
    marginTop: 12,
    width: 23
  },
  btn: {
    minWidth: 'auto',
    width: '100%',
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.gray_400;
    },
    color: function color(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.gray_500;
    },
    marginTop: 20,
    borderRadius: '10px',
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    },
    '&:active': {
      background: function background(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.primary;
      },
      color: function color(_ref5) {
        var palette = _ref5.theme.palette;
        return palette.light;
      }
    }
  },
  activeBtn: {
    background: function background(_ref6) {
      var palette = _ref6.theme.palette;
      return palette.primary;
    },
    color: function color(_ref7) {
      var palette = _ref7.theme.palette;
      return palette.light;
    },
    '&:active': {
      background: function background(_ref8) {
        var palette = _ref8.theme.palette;
        return palette.gray_400;
      },
      color: function color(_ref9) {
        var palette = _ref9.theme.palette;
        return palette.gray_500;
      }
    }
  },
  activeImg: {
    width: 16
  },
  typClass: {
    marginTop: 12,
    color: function color(_ref10) {
      var palette = _ref10.theme.palette;
      return palette.gray_500;
    }
  },
  activeTotalSavingTitle: {
    fontSize: 22,
    lineHeight: '30px'
  },
  priceWrapperActive: {
    fontWeight: 600
  },
  priceWrapper: {
    display: 'flex',
    alignItems: 'flex-end',
    fontSize: 28,
    lineHeight: '34px'
  },
  wrapperActive: {
    borderColor: function borderColor(_ref11) {
      var palette = _ref11.theme.palette;
      return palette.primary;
    },
    position: 'relative'
  },
  activePopUp: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    top: -20,
    left: -2,
    borderTopLeftRadius: '10px',
    borderTopRightRadius: '10px',
    lineHeight: '14px',
    fontWeight: 600,
    background: function background(_ref12) {
      var palette = _ref12.theme.palette;
      return palette.primary;
    },
    height: 32,
    width: 'calc(100% + 4px)',
    color: function color(_ref13) {
      var palette = _ref13.theme.palette;
      return palette.white;
    }
  })
});

// node modules
var PriceBlock = function PriceBlock(_ref) {
  var btnLabel = _ref.btnLabel,
      active = _ref.active,
      price = _ref.price,
      term = _ref.term,
      savingPrice = _ref.savingPrice,
      trialTitle = _ref.trialTitle,
      _ref$currency = _ref.currency,
      currency = _ref$currency === void 0 ? '$' : _ref$currency,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick;

  var _useStyles = useStyles$5({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      icon = _useStyles.icon,
      content = _useStyles.content,
      btn = _useStyles.btn,
      activeBtn = _useStyles.activeBtn,
      activeImg = _useStyles.activeImg,
      typClass = _useStyles.typClass,
      priceWrapper = _useStyles.priceWrapper,
      activeTotalSavingTitle = _useStyles.activeTotalSavingTitle,
      priceWrapperActive = _useStyles.priceWrapperActive,
      wrapperActive = _useStyles.wrapperActive,
      activePopUp = _useStyles.activePopUp;

  return React__default.createElement("div", {
    className: wrapper + " " + (active ? wrapperActive : '')
  }, React__default.createElement("div", {
    className: content
  }, React__default.createElement(Typography, {
    className: priceWrapper + " " + (active ? priceWrapperActive : ''),
    variant: "body1"
  }, currency, price, React__default.createElement(Typography, {
    variant: "body2"
  }, "/", term)), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, "Total saving"), React__default.createElement(Typography, {
    className: active ? activeTotalSavingTitle : '',
    variant: "title"
  }, currency, savingPrice), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, trialTitle), React__default.createElement("img", {
    className: icon + " " + (active ? activeImg : ''),
    src: active ? img$2 : img$1,
    alt: ""
  }), React__default.createElement(SimpleButton, {
    onClick: onClick,
    className: btn + " " + (active ? activeBtn : ''),
    label: btnLabel
  })), active && React__default.createElement(Typography, {
    className: activePopUp,
    variant: "label"
  }, "POPULAR"));
};

var useStyles$6 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'fixed',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    background: 'rgba(85, 84, 85, 0.8);'
  })
});

// node modules
var DialogContent = function DialogContent(_ref) {
  var children = _ref.children,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      _ref$rootClassName = _ref.rootClassName,
      rootClassName = _ref$rootClassName === void 0 ? '' : _ref$rootClassName;

  var _useStyles = useStyles$6(),
      root = _useStyles.root;

  return open ? React__default.createElement("div", {
    className: root + " " + rootClassName
  }, children, " ") : null;
};

// node modules

var showModal = function showModal(dialog) {
  var existingModal = document.getElementById('modalRoot');

  if (existingModal) {
    document.body.removeChild(existingModal);
  }

  var div = document.createElement('div');
  div.setAttribute('id', 'modalRoot');
  document.body.appendChild(div);
  return reactDom.createPortal(dialog, div);
};

var ModalWindow = function ModalWindow(props) {
  return showModal(React__default.createElement(DialogContent, Object.assign({}, props)));
};

var replaceLinks = function replaceLinks(str) {
  return str.replace(/\[([\s\S]*?)]/g, function (_, key) {
    var _key$split = key.split('|'),
        link = _key$split[0],
        linkName = _key$split[1];

    if (link && linkName) {
      return "<a target=\"_blank\" href=\"" + link.trim() + "\">" + linkName.trim() + "</a>";
    }

    return "[" + key + "]";
  });
};

var replaceTags = function replaceTags(_ref) {
  var symbol = _ref[0],
      tag = _ref[1];
  var regExp = new RegExp("\\" + symbol + "([\\s\\S]*?)\\" + symbol, 'g');
  return function (str) {
    return str.replace(regExp, "<" + tag + ">$1</" + tag + ">");
  };
};

// local files
var generateParser = function generateParser(options) {
  var parser = {};
  var tagWrappers = options.tagWrappers,
      brChanger = options.brChanger;

  if (tagWrappers) {
    if (typeof tagWrappers[0] === 'string') {
      parser.tagChangers = [replaceTags(tagWrappers)];
    }

    if (typeof tagWrappers[0] === 'object') {
      // @ts-ignore
      parser.tagChangers = tagWrappers.map(function (wrapper) {
        return replaceTags(wrapper);
      });
    }
  }

  if (brChanger) {
    parser.brChanger = function (s) {
      return s.replace(/\n/g, '<br>');
    };
  }

  return parser;
};

var replaceVariables = function replaceVariables(someStr, options) {
  var variables = options.variables,
      localStorageMode = options.localStorageMode;
  return someStr.replace(/%_([\s\S]*?)_%/g, function (_, key) {
    if (localStorageMode) {
      var valueFromLocalStorage = localStorage.getItem(key);

      if (valueFromLocalStorage) {
        return valueFromLocalStorage;
      }
    }

    if (variables[key]) {
      return variables[key].toString();
    }

    return '_';
  });
};

var setCorrectUppercaseLowercase = function setCorrectUppercaseLowercase(str) {
  var newString = str.replace(/\^_([\s\S]*?)_\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toLowerCase() + trimValue.slice(1);
  });
  newString = newString.replace(/\^-([\s\S]*?)-\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toUpperCase() + trimValue.slice(1);
  });
  return newString;
};

// local files
var TextNormalizer = function TextNormalizer(str, options) {
  var newString = str;
  var parser = generateParser(options);
  newString = replaceVariables(newString, options);
  newString = replaceLinks(newString);
  newString = setCorrectUppercaseLowercase(newString);
  if (parser.tagChangers) parser.tagChangers.forEach(function (cb) {
    return newString = cb(newString);
  });
  if (parser.brChanger) newString = parser.brChanger(newString);
  return newString;
};

// node modules
var useStyles$7 = /*#__PURE__*/reactJss.createUseStyles({
  slideClass: {
    transition: 'opacity 1s',
    opacity: 0
  },
  slideShowed: {
    opacity: 1
  }
});

// node modules

var waiting = function waiting(delay) {
  return new Promise(function (resolve) {
    setTimeout(resolve, delay);
  });
};

var ELEMENT_DELAY = 3000;
var TIMEOUT_DELAY = 1800;
var Slide = function Slide(_ref) {
  var handleNext = _ref.handleNext,
      content = _ref.content,
      color = _ref.color;

  var _useStyles = useStyles$7(),
      slideClass = _useStyles.slideClass,
      slideShowed = _useStyles.slideShowed;

  var _useState = React.useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  React.useEffect(function () {
    var delay = content.delay;
    waiting(delay || ELEMENT_DELAY).then(function () {
      setActiveClass(false);
      setTimeout(handleNext, TIMEOUT_DELAY);
    });
    setActiveClass(true);
  }, [content]);
  return React__default.createElement("div", {
    className: slideClass + " " + (activeClass ? slideShowed : '')
  }, content.image ? React__default.createElement("img", {
    src: content.value,
    alt: ""
  }) : React__default.createElement(Typography, {
    style: {
      color: content.color || color || null,
      textAlign: 'left'
    },
    variant: content.variant || 'bigTitle'
  }, parser(TextNormalizer(content.value, {
    brChanger: true,
    localStorageMode: true
  }))));
};

var useStyles$8 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.center, {
    width: '100%',
    height: '100vh'
  })
});

// node modules
var SliderPage = function SliderPage(_ref) {
  var _ref$elements = _ref.elements,
      elements = _ref$elements === void 0 ? [] : _ref$elements,
      onFinished = _ref.onFinished,
      background = _ref.background,
      textColor = _ref.textColor;

  var _useStyles = useStyles$8(),
      root = _useStyles.root;

  var _useState = React.useState(0),
      activeSlide = _useState[0],
      setActiveSlide = _useState[1];

  var handleNextSlide = function handleNextSlide() {
    if (activeSlide + 1 === elements.length) {
      if (onFinished) {
        onFinished();
      }
    } else {
      setActiveSlide(activeSlide + 1);
    }
  };

  return React__default.createElement("div", {
    className: root,
    style: {
      background: background
    }
  }, React__default.createElement(Slide, {
    color: textColor,
    handleNext: handleNextSlide,
    content: elements[activeSlide]
  }));
};

var img$3 = "data:image/svg+xml,%3csvg width='14' height='14' viewBox='0 0 14 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath fill-rule='evenodd' clip-rule='evenodd' d='M7 14C10.866 14 14 10.866 14 7C14 3.13401 10.866 0 7 0C3.13401 0 0 3.13401 0 7C0 10.866 3.13401 14 7 14ZM3.99988 4.7074L4.70698 4.00029L7.18201 6.47531L9.65703 4.00029L10.3641 4.7074L7.88911 7.18242L10.3638 9.65714L9.65673 10.3643L7.18201 7.88953L4.70728 10.3643L4.00017 9.65714L6.4749 7.18242L3.99988 4.7074Z' fill='%23C7C7C7'/%3e%3c/svg%3e";

var buttonInputCleanStyles = {
  border: 'none',
  outline: 'none',
  background: 'none'
};
var labelClassName = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.gray_200;
  },
  position: 'absolute',
  top: 0,
  left: 'calc(.75rem + 1px)',
  fontSize: '.875rem',
  lineHeight: '1.6rem',
  transform: 'translateY(calc(.75rem - 1px))',
  transition: 'all .2s ease',
  pointerEvents: 'none'
};
var activeLabelClassName = {
  fontSize: '.75rem',
  lineHeight: '1.8rem',
  transform: 'translateY(0)'
};
var labelWrapperRoot = {
  position: 'relative',
  border: function border(_ref2) {
    var palette = _ref2.theme.palette;
    return "1px solid " + palette.light_gray;
  },
  borderRadius: '.625rem',
  boxSizing: 'border-box'
};
var inputSelectCommonStylesProps = /*#__PURE__*/_extends({}, buttonInputCleanStyles, {
  all: 'unset',
  display: 'block',
  width: '100%',
  padding: '20px 0 5px .75rem',
  boxSizing: 'border-box',
  fontSize: '1rem',
  lineHeight: '1rem',
  borderRadius: '.625rem'
});
var disabled = {
  cursor: 'not-allowed',
  opacity: .4
};
var errorClass = {
  borderColor: function borderColor(_ref3) {
    var palette = _ref3.theme.palette;
    return palette.error;
  }
};

var useStyles$9 = /*#__PURE__*/reactJss.createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  root: /*#__PURE__*/_extends({}, labelWrapperRoot, {
    display: 'flex',
    paddingRight: 16
  }),
  input: /*#__PURE__*/_extends({}, inputSelectCommonStylesProps, {
    width: '100%',
    textAlign: 'left',
    fontFamily: 'SF Pro Text'
  }),
  inputAdorned: {
    left: '30px !important'
  },
  inputAdornedActive: {
    left: '32px !important'
  },
  unlabeled: {
    padding: '12px 0 12px .75rem'
  },
  labelClass: /*#__PURE__*/_extends({}, labelClassName),
  active: /*#__PURE__*/_extends({}, activeLabelClassName),
  disabledClass: /*#__PURE__*/_extends({}, disabled),
  errorClass: /*#__PURE__*/_extends({}, errorClass),
  typeWrapper: /*#__PURE__*/_extends({}, alignment.center, {
    paddingLeft: 11,
    whiteSpace: 'nowrap'
  }),
  typeWrapperStart: /*#__PURE__*/_extends({}, alignment.center, {
    paddingRight: 11
  }),
  clearIconClass: {
    cursor: 'pointer',
    paddingLeft: 11
  }
});

var Input = function Input(_ref) {
  var _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      labelClassName = _ref.labelClassName,
      rootClassName = _ref.rootClassName,
      onChange = _ref.onChange,
      label = _ref.label,
      value = _ref.value,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      adornmentEnd = _ref.adornmentEnd,
      adornmentStart = _ref.adornmentStart,
      closeIcon = _ref.closeIcon,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["error", "type", "disabled", "labelClassName", "rootClassName", "inputClassName", "onChange", "label", "value", "onFocus", "onBlur", "adornmentEnd", "adornmentStart", "closeIcon"]);

  var _useStyles = useStyles$9({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      labelClass = _useStyles.labelClass,
      active = _useStyles.active,
      input = _useStyles.input,
      unlabeled = _useStyles.unlabeled,
      disabledClass = _useStyles.disabledClass,
      errorClass = _useStyles.errorClass,
      typeWrapper = _useStyles.typeWrapper,
      clearIconClass = _useStyles.clearIconClass,
      inputAdorned = _useStyles.inputAdorned,
      inputAdornedActive = _useStyles.inputAdornedActive;

  var inputEl = React.useRef({});

  var _useState = React.useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  var _useState2 = React.useState(value || ''),
      inputValue = _useState2[0],
      setInputValue = _useState2[1];

  var handleFocus = function handleFocus(e) {
    if (disabled) return;
    setActiveClass(true);

    if (onFocus) {
      onFocus(e);
    }
  };

  var handleBlur = function handleBlur(e) {
    setActiveClass(!!e.target.value);

    if (onBlur) {
      onBlur(e);
    }
  };

  var handleChange = function handleChange(e) {
    setInputValue(e.target.value);

    if (onChange) {
      onChange(e);
    }
  };

  var handleClean = function handleClean() {
    setInputValue('');
    var evt = new Event('change');
    var current = inputEl.current;
    current.value = '';

    var event = _extends({}, evt, {
      target: current,
      currentTarget: current
    });

    if (onChange) {
      onChange(event);
    }

    current.focus();
  };

  var adornmentClass = '';

  if (adornmentStart) {
    adornmentClass = inputAdorned + " " + (!!inputValue || activeClass ? inputAdornedActive : '');
  }

  var classNameLabel = labelClass + " " + labelClassName + " " + (!!inputValue || activeClass ? active : '') + " " + adornmentClass;
  var rootClass = root + " " + rootClassName + " " + (disabled ? disabledClass : '') + " " + (error ? errorClass : '');
  var inputClass = input + " " + (!label ? unlabeled : '');
  return React__default.createElement("div", {
    className: rootClass
  }, adornmentStart && React__default.createElement("div", {
    className: typeWrapper
  }, React__default.createElement(Typography, {
    variant: "body1"
  }, adornmentStart)), label && React__default.createElement(Typography, {
    variant: "body2",
    className: classNameLabel
  }, label), React__default.createElement("input", Object.assign({
    ref: inputEl,
    type: type,
    disabled: disabled,
    onBlur: handleBlur,
    onFocus: handleFocus,
    className: inputClass,
    value: inputValue,
    onChange: handleChange
  }, otherProps)), adornmentEnd && React__default.createElement("div", {
    className: typeWrapper
  }, React__default.createElement(Typography, {
    variant: "body1"
  }, adornmentEnd)), closeIcon && React__default.createElement("img", {
    className: clearIconClass,
    onClick: handleClean,
    src: img$3,
    alt: ""
  }));
};

// node modules
var useStyles$a = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    position: 'relative',
    height: 48,
    borderRadius: '.5rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light_gray;
    }
  },
  text: {
    position: 'absolute',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    },
    zIndex: 1
  },
  childBar: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '.5rem',
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.primary;
    },
    transition: 'width .3s'
  }
});

// node modules
var ProgressBar = function ProgressBar(_ref) {
  var percents = _ref.percents,
      className = _ref.className;

  var _useStyles = useStyles$a({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      childBar = _useStyles.childBar,
      text = _useStyles.text;

  var width = "calc(100% * " + percents / 100 + ")";
  return React__default.createElement("div", {
    className: wrapper + " " + className
  }, React__default.createElement("span", {
    className: text
  }, percents, " %"), React__default.createElement("div", {
    className: childBar,
    style: {
      width: width
    }
  }));
};

var useStyles$b = /*#__PURE__*/reactJss.createUseStyles({
  progressWrapper: {
    position: 'relative',
    height: 8,
    borderRadius: '1.875rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.gray;
    }
  },
  progress: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '1.875rem',
    transition: 'width .3s'
  },
  infoWrapper: /*#__PURE__*/_extends({
    marginBottom: 8
  }, alignment.betweenCenter)
});

// node modules
var ProgressBarThin = function ProgressBarThin(_ref) {
  var _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? palette.primary : _ref$color,
      _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? true : _ref$completed,
      title = _ref.title,
      className = _ref.className;

  var _useStyles = useStyles$b({
    theme: theming.useTheme()
  }),
      progressWrapper = _useStyles.progressWrapper,
      progress = _useStyles.progress,
      infoWrapper = _useStyles.infoWrapper;

  var width = "calc(100% * " + percents / 100 + ")";
  var variant = completed ? 'body2' : 'h3';
  return React__default.createElement("div", {
    className: className
  }, React__default.createElement("div", {
    className: infoWrapper
  }, React__default.createElement(Typography, {
    variant: variant,
    style: {
      color: color
    }
  }, title), React__default.createElement(Typography, {
    variant: variant,
    style: {
      color: color
    }
  }, percents, " %")), React__default.createElement("div", {
    className: progressWrapper
  }, React__default.createElement("div", {
    className: progress,
    style: {
      background: color,
      width: width
    }
  })));
};

var img$4 = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: white %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

// node modules
var getCorrectInput = function getCorrectInput(i, steps, percents) {
  if (!i) return '';
  if (i / steps * 100 <= percents) return React__default.createElement("img", {
    style: {
      width: 9
    },
    src: img$4,
    alt: ""
  });
  return i;
};
var getCorrectColor = function getCorrectColor(i, steps, percents, colors) {
  if (i / steps * 100 <= percents) {
    return !colors[i - 1] ? colors[i] : colors[i - 1];
  }

  return palette.light_gray;
};
var getIndexColorToTitle = function getIndexColorToTitle(correctPercents, steps, colors) {
  var index = Math.floor(steps * correctPercents / 100);

  if (index === colors.length) {
    index = index - 1;
  }

  return index;
};

var createUniqIdGenerator = function createUniqIdGenerator() {
  var number = 0;
  return function () {
    return "id--" + number++;
  };
};

var uniqIdGenerator = /*#__PURE__*/createUniqIdGenerator();

var useStyles$c = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    width: '100%',
    minWidth: 200,
    position: 'relative',
    height: 6,
    marginBottom: 17
  },
  cercle: /*#__PURE__*/_extends({
    fontFamily: 'SF Pro Display',
    position: 'absolute',
    top: '50%',
    transform: 'translate(-50%, -50%)',
    width: 16,
    height: 16,
    borderRadius: '50%'
  }, alignment.center, {
    fontSize: 11,
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.white;
    }
  }),
  bar: {
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    height: 8
  },
  coverBlock: /*#__PURE__*/_extends({
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    right: 0,
    width: '100%',
    height: 10,
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    }
  }, alignment.center, {
    transition: 'width .3s',
    minWidth: 0
  }),
  thinBlock: {
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.light_gray;
    },
    width: '100%',
    height: 6
  },
  root: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  paddingWrapper: {
    padding: '5px 8px 0'
  }
});

// node modules
var ProgressStepper = function ProgressStepper(_ref) {
  var steps = _ref.steps,
      colors = _ref.colors,
      _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      title = _ref.title;

  var _useStyles = useStyles$c({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      cercle = _useStyles.cercle,
      bar = _useStyles.bar,
      coverBlock = _useStyles.coverBlock,
      thinBlock = _useStyles.thinBlock,
      root = _useStyles.root,
      paddingWrapper = _useStyles.paddingWrapper;

  var generatedArray = new Array(steps + 1).fill(true);
  var correctPercents = percents <= 0 || isNaN(percents) ? 1 : percents;
  correctPercents = correctPercents > 100 ? 100 : correctPercents;
  return React__default.createElement("div", {
    className: paddingWrapper
  }, React__default.createElement("div", {
    className: root
  }, React__default.createElement("div", {
    className: wrapper
  }, generatedArray.map(function (_, i) {
    return React__default.createElement(React.Fragment, {
      key: uniqIdGenerator()
    }, !!i && React__default.createElement("span", {
      style: {
        left: 0,
        width: "calc(" + i + "/" + steps + " * 100%)",
        background: colors[i - 1],
        zIndex: steps + 1 - i
      },
      className: bar
    }), React__default.createElement("span", {
      style: {
        left: "calc(" + i + "/" + steps + " * 100%)",
        zIndex: generatedArray.length + 2,
        background: getCorrectColor(i, steps, percents, colors)
      },
      className: cercle
    }, getCorrectInput(i, steps, correctPercents)));
  }), React__default.createElement("div", {
    style: {
      zIndex: generatedArray.length + 1,
      width: "calc(100% - " + correctPercents + "%)"
    },
    className: coverBlock
  }, React__default.createElement("div", {
    className: thinBlock
  }))), React__default.createElement(Typography, {
    style: {
      color: colors[getIndexColorToTitle(correctPercents, steps, colors)]
    },
    variant: "h4"
  }, title)));
};

var useStyles$d = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    minWidth: 200
  },
  tabWrapper: /*#__PURE__*/_extends({}, alignment.betweenCenter, {
    height: 32,
    padding: 2,
    borderRadius: 8,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    }
  }),
  activeBtn: {
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    }
  },
  btn: {
    minWidth: 'auto',
    padding: 0,
    height: '100%',
    borderRadius: 8
  }
});

// node modules
var Tab = function Tab(_ref) {
  var list = _ref.list,
      _ref$activeTab = _ref.activeTab,
      activeTab = _ref$activeTab === void 0 ? 0 : _ref$activeTab,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? '100%' : _ref$width,
      _ref$contentClass = _ref.contentClass,
      contentClass = _ref$contentClass === void 0 ? '' : _ref$contentClass,
      _ref$tabWrapperClass = _ref.tabWrapperClass,
      tabWrapperClass = _ref$tabWrapperClass === void 0 ? '' : _ref$tabWrapperClass,
      _ref$tabClass = _ref.tabClass,
      tabClass = _ref$tabClass === void 0 ? '' : _ref$tabClass,
      tabs = _ref.tabs,
      onChange = _ref.onChange;

  var _useStyles = useStyles$d({
    theme: theming.useTheme()
  }),
      tabWrapper = _useStyles.tabWrapper,
      activeBtn = _useStyles.activeBtn,
      btn = _useStyles.btn,
      wrapper = _useStyles.wrapper;

  var _useState = React.useState(activeTab),
      currentTab = _useState[0],
      setCurrentTab = _useState[1];

  React.useEffect(function () {
    setCurrentTab(activeTab);
  }, [activeTab]);
  React.useEffect(function () {
    if (onChange) onChange(currentTab);
  }, [currentTab]);
  if (tabs != null && tabs.length) return React__default.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React__default.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, tabs.map(function (title, i) {
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React__default.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + tabs.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React__default.createElement(Typography, {
        variant: "label"
      }, title)
    });
  })));
  return React__default.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React__default.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, list.map(function (_ref2, i) {
    var title = _ref2.title;
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React__default.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + list.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React__default.createElement(Typography, {
        variant: "label"
      }, title)
    });
  })), React__default.createElement("div", {
    className: contentClass
  }, list[currentTab].Content));
};

// node modules
var useStyles$e = /*#__PURE__*/reactJss.createUseStyles({
  enter: {
    opacity: 0,
    transform: 'translateX(20px)'
  },
  enterActive: {
    opacity: 1,
    transform: 'translateX(0)',
    transition: function transition(_ref) {
      var timeout = _ref.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    },
    transitionTimingFunction: 'ease-out'
  },
  exit: {
    opacity: 1
  },
  exitActive: {
    opacity: 0,
    transform: 'translate(20px)',
    transition: function transition(_ref2) {
      var timeout = _ref2.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    }
  }
});

var AnimationWrapper = function AnimationWrapper(_ref) {
  var children = _ref.children,
      delay = _ref.delay,
      disabled = _ref.disabled,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["children", "delay", "disabled"]);

  var timeout = otherProps.timeout,
      className = otherProps.className;

  var _useState = React.useState(false),
      showed = _useState[0],
      setShowed = _useState[1];

  var classes = useStyles$e({
    theme: {
      timeout: timeout
    }
  });
  React.useEffect(function () {
    if (!disabled && delay !== undefined) {
      setTimeout(function () {
        return setShowed(true);
      }, delay);
    }
  }, []);
  if (disabled) return children;
  return React__default.createElement(reactTransitionGroup.CSSTransition, Object.assign({}, otherProps, {
    "in": showed,
    unmountOnExit: true,
    classNames: _extends({}, classes)
  }), React__default.createElement("div", {
    className: className || ''
  }, children));
};

exports.AnimationWrapper = AnimationWrapper;
exports.CheckButton = CheckButton;
exports.Input = Input;
exports.ModalWindow = ModalWindow;
exports.PriceBlock = PriceBlock;
exports.PrimaryButton = PrimaryButton;
exports.ProgressBar = ProgressBar;
exports.ProgressBarThin = ProgressBarThin;
exports.ProgressStepper = ProgressStepper;
exports.SelectButton = SelectButton;
exports.SimpleButton = SimpleButton;
exports.SliderPage = SliderPage;
exports.Tab = Tab;
exports.TextNormalizer = TextNormalizer;
exports.Typography = Typography;
//# sourceMappingURL=ruby-web-common.cjs.development.js.map
