// node modules
import React, { FC, useState } from 'react';

// local components
import { Slide } from './slide';

// local files
import { SliderProps } from "./slide";
import { useStyles } from "./styles";

export interface SliderPageProps {
    textColor?: string;
    background: string,
    elements: SliderProps[],
    onFinished: () => void;
}

export const SliderPage: FC<SliderPageProps> = ({
    elements= [],
    onFinished,
    background,
    textColor
}) => {
    const { root } = useStyles();
    const [activeSlide, setActiveSlide] = useState(0);

    const handleNextSlide = () => {
        if (activeSlide + 1 === elements.length) {
            if (onFinished) {
                onFinished()
            }
        } else {
            setActiveSlide(activeSlide + 1)
        }
    }


    return (
        <div className={root} style={{ background }}>
            <Slide
                color={textColor}
                handleNext={handleNextSlide}
                content={elements[activeSlide]}
            />
        </div>
    )
};
