// node modules
import React, { FC, useEffect, useState } from 'react';
import parser from 'html-react-parser';

// local files
import { Typography } from "../../typography";
import { TextNormalizer } from "../../parser";

// local files
import { useStyles } from "./styles";

export type SliderProps = {
    image?: boolean;
    value: string;
    delay?: number;
    color?: string;
    variant?: 'body1' | 'h3' | 'h2' | 'h4' | 'label' |  'body2' | 'title' | 'bigTitle'
}

interface SlideContentProps {
    handleNext: () => void;
    content: SliderProps;
    color?: string;
}

const waiting = (delay: number) => {
    return new Promise(resolve => {
        setTimeout(resolve, delay)
    })
}

const ELEMENT_DELAY = 3000;
const TIMEOUT_DELAY = 1800;

export const Slide: FC<SlideContentProps> = ({ handleNext, content, color }) => {
    const { slideClass, slideShowed } = useStyles();
    const [activeClass, setActiveClass] = useState(false);

    useEffect(() => {
        const { delay } = content;

        waiting(delay || ELEMENT_DELAY).then(() => {
            setActiveClass(false);
            setTimeout(handleNext, TIMEOUT_DELAY)
        });

        setActiveClass(true);
    }, [content]);

    return (
        <div className={`${slideClass} ${activeClass ? slideShowed : ''}`}>
            {content.image
                ? <img src={content.value} alt=""/>
                : (
                    <Typography
                        style={{ color: content.color || color || null, textAlign: 'left' }}
                        variant={content.variant || 'bigTitle'}
                    >
                        {parser(TextNormalizer(
                            content.value,
                            {
                                brChanger: true,
                                localStorageMode: true
                            }
                        ))}
                    </Typography>
                )
            }

        </div>
    )
};
